summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorOlivier Blin <oblin@mandriva.org>2005-11-08 16:33:42 +0000
committerOlivier Blin <oblin@mandriva.org>2005-11-08 16:33:42 +0000
commit84f9a30da5fddd60a141fd4aa9ef6a31168ca4ee (patch)
tree50b8cf0d52ddd1639766491a40a5494926dc9f43
parent7172f67b83864e2b889291ed6200aebf5c1c2bab (diff)
downloaddrakx-backup-do-not-use-84f9a30da5fddd60a141fd4aa9ef6a31168ca4ee.tar
drakx-backup-do-not-use-84f9a30da5fddd60a141fd4aa9ef6a31168ca4ee.tar.gz
drakx-backup-do-not-use-84f9a30da5fddd60a141fd4aa9ef6a31168ca4ee.tar.bz2
drakx-backup-do-not-use-84f9a30da5fddd60a141fd4aa9ef6a31168ca4ee.tar.xz
drakx-backup-do-not-use-84f9a30da5fddd60a141fd4aa9ef6a31168ca4ee.zip
fix zd1201 devices detection as well
-rw-r--r--perl-install/network/ethernet.pm5
1 files changed, 3 insertions, 2 deletions
diff --git a/perl-install/network/ethernet.pm b/perl-install/network/ethernet.pm
index ec4073ee0..8cf673359 100644
--- a/perl-install/network/ethernet.pm
+++ b/perl-install/network/ethernet.pm
@@ -91,10 +91,11 @@ sub get_eth_cards {
my @cards = grep { my $dev = $_; every { $dev->{$_} eq $l{$_} } keys %l } detect_devices::probeall();
$description ||= $cards[0]{description} if @cards == 1;
} elsif (!$a && -e "/sys/class/net/$interface/wireless") {
# probably a rt2400/rt2500 device (PCI or PCMCIA CardBus)
# these broken drivers don't create the "device" link
# try to see if rt2400/rt2500 is loaded, and assume current wireless device uses it
$a = find { -e "/sys/bus/pci/drivers/$_" } qw(rt2400 rt2500);
+ $a ||= find { -e "/sys/bus/usb/drivers/$_" } qw(zd1201);
}
}
# 6) try to match a device by driver for device description:
@@ -91,10 +91,11 @@ sub get_eth_cards {
$description ||= $cards[0]{description} if @cards == 1;
} elsif (!$a && -e "/sys/class/net/$interface/wireless") {
- # probably a rt2400/rt2500 device (PCI or PCMCIA CardBus)
+ # probably a rt2400/rt2500 device (PCI or PCMCIA CardBus) or zd1201 (USB)
# these broken drivers don't create the "device" link
@@ -91,10 +91,11 @@ sub get_eth_cards {
# these broken drivers don't create the "device" link
- # try to see if rt2400/rt2500 is loaded, and assume current wireless device uses it
+ # try to see if rt2400/rt2500/zd1201 is is loaded, and assume current wireless device uses it
$a = find { -e "/sys/bus/pci/drivers/$_" } qw(rt2400 rt2500);